==> haskell-retrie-1.2.2-23-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-retrie.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 retrie
version:              1.2.2
visibility:           public
id:                   retrie-1.2.2-8Y8YYCrF79X2C3bocn8cGV
key:                  retrie-1.2.2-8Y8YYCrF79X2C3bocn8cGV
license:              MIT
copyright:            Copyright (c) Facebook, Inc. and its affiliates.
maintainer:           Andrew Farmer <anfarmer@fb.com>
author:               Andrew Farmer <anfarmer@fb.com>
homepage:             https://github.com/facebookincubator/retrie
synopsis:             A powerful, easy-to-use codemodding tool for Haskell.
description:
    Retrie is a tool for codemodding Haskell. Key goals include:

    * Speed: Efficiently rewrite in large (>1 million line) codebases.
    * Safety: Avoids large classes of codemod-related errors.
    * Ease-of-use: Haskell syntax instead of regular expressions. No hand-rolled AST traversals.

    This package provides a command-line tool (@retrie@) and a library
    ("Retrie") for making equational edits to Haskell code.

    Please see the [README](#readme) for examples and usage.

category:             Development
abi:                  be90c8811b847322f658964e7da82534
exposed:              True
exposed-modules:
    Retrie Retrie.AlphaEnv Retrie.CPP Retrie.Context Retrie.Debug
    Retrie.Elaborate Retrie.ExactPrint Retrie.ExactPrint.Annotated
    Retrie.Expr Retrie.Fixity Retrie.FreeVars Retrie.GHC
    Retrie.GroundTerms Retrie.Monad Retrie.Options
    Retrie.PatternMap.Bag Retrie.PatternMap.Class
    Retrie.PatternMap.Instances Retrie.Pretty Retrie.Quantifiers
    Retrie.Query Retrie.Replace Retrie.Rewrites
    Retrie.Rewrites.Function Retrie.Rewrites.Patterns
    Retrie.Rewrites.Rules Retrie.Rewrites.Types Retrie.Run Retrie.SYB
    Retrie.Subst Retrie.Substitution Retrie.Types Retrie.Universe
    Retrie.Util

import-dirs:          /usr/lib/ghc-9.2.8/site-local/retrie-1.2.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/retrie-1.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-retrie
hs-libraries:         HSretrie-1.2.2-8Y8YYCrF79X2C3bocn8cGV
depends:
    ansi-terminal-0.11.5-FgXvUwo3mIX2g72exyhUhE
    async-2.2.5-Hxx4nU8aNwh7V1GfZTZX85 base-4.16.4.0
    bytestring-0.11.4.0 containers-0.6.5.1
    data-default-0.7.1.1-JYvfHll1aet2HYdPlRdwv9 directory-1.3.6.2
    filepath-1.4.2.2 ghc-9.2.8
    ghc-exactprint-1.5.0-HXVoV4M5yQt8hu0DDQNuW5
    list-t-1.0.5.4-LWiXdd1SWXLJ5ZwTilo6U3 mtl-2.2.2
    optparse-applicative-0.17.1.0-AgMeQrX7nmlDOnX2xcegDb
    process-1.6.16.0 random-shuffle-0.0.4-EGfHKrXkm6WJY9StYqUWot
    syb-0.7.2.4-4iiIjHgm67gJA1HTgFmr8s text-1.2.5.0
    transformers-0.5.6.2
    unordered-containers-0.2.20-4hqmnCstShmJXjUlp61Lcu

haddock-interfaces:   /usr/share/doc/haskell-retrie/html/retrie.haddock
haddock-html:         /usr/share/doc/haskell-retrie/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-retrie-1.2.3-58.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-retrie.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 retrie
version:              1.2.3
visibility:           public
id:                   retrie-1.2.3-FK877bzOi9SDfC4ocTeA9
key:                  retrie-1.2.3-FK877bzOi9SDfC4ocTeA9
license:              MIT
copyright:            Copyright (c) Facebook, Inc. and its affiliates.
maintainer:           Andrew Farmer <anfarmer@fb.com>
author:               Andrew Farmer <anfarmer@fb.com>
homepage:             https://github.com/facebookincubator/retrie
synopsis:             A powerful, easy-to-use codemodding tool for Haskell.
description:
    Retrie is a tool for codemodding Haskell. Key goals include:

    * Speed: Efficiently rewrite in large (>1 million line) codebases.
    * Safety: Avoids large classes of codemod-related errors.
    * Ease-of-use: Haskell syntax instead of regular expressions. No hand-rolled AST traversals.

    This package provides a command-line tool (@retrie@) and a library
    ("Retrie") for making equational edits to Haskell code.

    Please see the [README](#readme) for examples and usage.

category:             Development
abi:                  1ac369d4366650b5f214a5fb322ca302
exposed:              True
exposed-modules:
    Retrie Retrie.AlphaEnv Retrie.CPP Retrie.Context Retrie.Debug
    Retrie.Elaborate Retrie.ExactPrint Retrie.ExactPrint.Annotated
    Retrie.Expr Retrie.Fixity Retrie.FreeVars Retrie.GHC
    Retrie.GroundTerms Retrie.Monad Retrie.Options
    Retrie.PatternMap.Bag Retrie.PatternMap.Class
    Retrie.PatternMap.Instances Retrie.Pretty Retrie.Quantifiers
    Retrie.Query Retrie.Replace Retrie.Rewrites
    Retrie.Rewrites.Function Retrie.Rewrites.Patterns
    Retrie.Rewrites.Rules Retrie.Rewrites.Types Retrie.Run Retrie.SYB
    Retrie.Subst Retrie.Substitution Retrie.Types Retrie.Universe
    Retrie.Util

import-dirs:          /usr/lib/ghc-9.4.8/site-local/retrie-1.2.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/retrie-1.2.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/retrie-1.2.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-retrie
hs-libraries:         HSretrie-1.2.3-FK877bzOi9SDfC4ocTeA9
depends:
    ansi-terminal-1.0.2-CHKNXEXhuZ3EvZtvAUncPO
    async-2.2.5-CjCuZi34HovIas1x5o0XNl base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7
    data-default-0.7.1.1-HuI8bY4bNR4F11jcRg6vOi directory-1.3.7.1
    filepath-1.4.2.2 ghc-9.4.8
    ghc-exactprint-1.6.1-7VevvuiZbEr3xPBlpJ7Rs3
    list-t-1.0.5.5-KItJxutFk4WFX7WyoP0Vt2 mtl-2.2.2
    optparse-applicative-0.17.1.0-3DJFXm9vTXK45PcUNAvg30
    process-1.6.18.0 random-shuffle-0.0.4-6lU4Ws51doBCF2BVRRBCLf
    syb-0.7.2.4-2YD6CDfMmJX8WUaza11ezv text-2.0.2 transformers-0.5.6.2
    unordered-containers-0.2.20-WenrpHtwHKIVom5hXYF7C

haddock-interfaces:   /usr/share/doc/haskell-retrie/html/retrie.haddock
haddock-html:         /usr/share/doc/haskell-retrie/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
